# pypackages-info
A simple tool. Can output the name, version, last modified time, and location of the installed module in the current environment in a tabular form at the terminal.


```bash
pip insatll .
pypackage-info
python -m pypackage-info
```

![1695647724716](https://github.com/PCCAG/pypackages-info/blob/master/image/readme/1695647724716.png?raw=true)
